Here you can find numerous example notebooks providing tutorials into GeometricKernels.

Each of the *Spaces* notebooks explains the basic functionality of the library in relation to a specific space.

If you are interested in using GeometricKernels with a backend other than NumPy, checkout the *Backends* notebooks.

If you want to use GeometricKernels with one of the popular Gaussian process libraries, checkout the *Frontends* notebooks.